@@ -278,6 +278,62 @@ sub _onpub_moveid {
 
 # -- Playlist: managing playlists
 
+#
+# event: pl.load( $playlist );
+#
+# Load list of songs from specified $playlist file.
+#
+sub _onpub_load {
+    my ($playlist) = $_[ARG0];
+    my $msg = POE::Component::Client::MPD::Message->new( {
+        _from     => $_[SENDER]->ID,
+        _request  => $_[STATE],
+        _answer   => $DISCARD,
+        _commands => [ qq[load "$playlist"] ],
+        _cooking  => $RAW,
+    } );
+    $_[KERNEL]->yield( '_send', $msg );
+}
+
+
+#
+# event: pl.save( $playlist );
+#
+# Save the current playlist to a file called $playlist in MPD's
+# playlist directory.
+#
+sub _onpub_save {
+    my ($playlist) = $_[ARG0];
+    my $msg = POE::Component::Client::MPD::Message->new( {
+        _from     => $_[SENDER]->ID,
+        _request  => $_[STATE],
+        _answer   => $DISCARD,
+        _commands => [ qq[save "$playlist"] ],
+        _cooking  => $RAW,
+    } );
+    $_[KERNEL]->yield( '_send', $msg );
+}
+
+
+#
+# event: pl.save( $playlist );
+#
+# Delete playlist named $playlist from MPD's playlist directory.
+#
+sub _onpub_rm {
+    my ($playlist) = $_[ARG0];
+    my $msg = POE::Component::Client::MPD::Message->new( {
+        _from     => $_[SENDER]->ID,
+        _request  => $_[STATE],
+        _answer   => $DISCARD,
+        _commands => [ qq[rm "$playlist"] ],
+        _cooking  => $RAW,
+    } );
+    $_[KERNEL]->yield( '_send', $msg );
+}
+
+
+
 1;
 
 __END__
